function dP = pipeLoadDelta(t,d,P,Leff,E,Sy)
% pipeLoadDelta  Difference between applied and critical loads for a pipe in compression
%
% Synopsis:  dP = pipeLoadDelta(t,d,P,Leff,E,Sy)
%
% Input: t = pipe wall thickness
%        d = pipe diameter
%        P = applied load
%        Leff = effective length of the pipe
%        E = elastic modulus of the pipe material
%        Sy = yield stress of pipe material
%
% Output:  dP = Pcr - P = amount by which the critical buckling load exceeds
%               the applied load for the pipe.
%
% Note:  The user is responsible for insuring that all input variables
%        have consistent units
